"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseCommand = void 0;
const cli_command_1 = require("@contentstack/cli-command");
const cli_utilities_1 = require("@contentstack/cli-utilities");
class BaseCommand extends cli_command_1.Command {
    /**
     * The `init` function initializes the command by parsing arguments and flags, registering search
     * plugins, registering the configuration, and initializing the logger.
     */
    async init() {
        await super.init();
        // Init logger
        this.logger = new cli_utilities_1.LoggerService(process.cwd(), 'cli-log');
    }
    /**
     * The catch function is used to handle errors from a command, either by adding custom logic or
     * returning the parent class error handling.
     * @param err - The `err` parameter is of type `Error & { exitCode?: number }`. This means that it is
     * an object that extends the `Error` class and may also have an optional property `exitCode` of type
     * `number`.
     * @returns The parent class error handling is being returned.
     */
    async catch(err) {
        // add any custom logic to handle errors from the command
        // or simply return the parent class error handling
        return super.catch(err);
    }
    /**
     * The `finally` function is called after the `run` and `catch` functions, regardless of whether or not
     * an error occurred.
     * @param {Error | undefined} _ - The parameter "_" represents an error object or undefined.
     * @returns The `finally` method is returning the result of calling the `finally` method of the
     * superclass, which is a promise.
     */
    async finally(_) {
        // called after run and catch regardless of whether or not the command errored
        return super.finally(_);
    }
}
exports.BaseCommand = BaseCommand;
