"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cli_command_1 = require("@contentstack/cli-command");
const cli_utilities_1 = require("@contentstack/cli-utilities");
const utils_1 = require("../../../utils");
class BranchSetCommand extends cli_command_1.Command {
    async run() {
        try {
            const { flags: branchSetFlags } = await this.parse(BranchSetCommand);
            let apiKey = branchSetFlags['stack-api-key'];
            let baseBranch = branchSetFlags['base-branch'];
            if (!apiKey) {
                apiKey = await utils_1.interactive.askStackAPIKey();
            }
            if (!baseBranch) {
                baseBranch = await utils_1.interactive.askBaseBranch();
            }
            cli_utilities_1.configHandler.set(`baseBranch.${apiKey}`, baseBranch);
            cli_utilities_1.cliux.success(`base branch : ${baseBranch}`);
            cli_utilities_1.cliux.success(`stack-api-key: ${apiKey}`);
            cli_utilities_1.cliux.success(`Base branch configuration for stack-api-key: ${apiKey} and branch: ${baseBranch} set successfully`);
        }
        catch (error) {
            cli_utilities_1.cliux.error('error', error);
        }
    }
}
exports.default = BranchSetCommand;
BranchSetCommand.description = 'Set branch for CLI';
BranchSetCommand.flags = {
    'stack-api-key': cli_utilities_1.flags.string({ char: 'k', description: 'Stack API Key' }),
    'base-branch': cli_utilities_1.flags.string({ description: 'Base Branch' }),
};
BranchSetCommand.examples = [
    '$ csdx config:set:base-branch',
    '$ csdx config:set:base-branch --stack-api-key <value> --base-branch <value>',
];
