"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cli_utilities_1 = require("@contentstack/cli-utilities");
const utils_1 = require("../../../utils");
const base_command_1 = require("../../../base-command");
class RegionSetCommand extends base_command_1.BaseCommand {
    async run() {
        const { args, flags: regionSetFlags } = await this.parse(RegionSetCommand);
        let cda = regionSetFlags.cda;
        let cma = regionSetFlags.cma;
        let name = regionSetFlags.name;
        let uiHost = regionSetFlags['ui-host'];
        let selectedRegion = args.region;
        if (!(cda && cma && uiHost && name) && !selectedRegion) {
            selectedRegion = await utils_1.interactive.askRegions();
        }
        if (selectedRegion === 'custom') {
            const selectedCustomRegion = await utils_1.interactive.askCustomRegion();
            name = selectedCustomRegion.name;
            cda = selectedCustomRegion.cda;
            cma = selectedCustomRegion.cma;
            uiHost = selectedCustomRegion.uiHost;
        }
        else if (selectedRegion === 'exit') {
            this.exit();
        }
        // Custom flag will get first priority over region argument
        if (cda && cma && uiHost && name) {
            try {
                let customRegion = { cda, cma, uiHost, name };
                customRegion = utils_1.regionHandler.setCustomRegion(customRegion);
                await cli_utilities_1.authHandler.setConfigData('logout'); //Todo: Handle this logout flow well through logout command call
                cli_utilities_1.cliux.success(`Custom region has been set to ${customRegion.name}`);
                cli_utilities_1.cliux.success(`CMA HOST: ${customRegion.cma}`);
                cli_utilities_1.cliux.success(`CDA HOST: ${customRegion.cda}`);
                cli_utilities_1.cliux.success(`UI HOST: ${customRegion.uiHost}`);
            }
            catch (error) {
                this.logger.error('failed to set the region', error);
                cli_utilities_1.cliux.error(`Failed to set region due to: ${error.message}`);
            }
        }
        else if (['NA', 'EU', 'AZURE-NA', 'AZURE-EU'].includes(selectedRegion)) {
            const regionDetails = utils_1.regionHandler.setRegion(selectedRegion);
            await cli_utilities_1.authHandler.setConfigData('logout'); //Todo: Handle this logout flow well through logout command call
            cli_utilities_1.cliux.success(`Region has been set to ${regionDetails.name}`);
            cli_utilities_1.cliux.success(`CDA HOST: ${regionDetails.cda}`);
            cli_utilities_1.cliux.success(`CMA HOST: ${regionDetails.cma}`);
            cli_utilities_1.cliux.success(`UI HOST: ${regionDetails.uiHost}`);
        }
        else {
            cli_utilities_1.cliux.error(`Invalid region is given`);
        }
    }
}
exports.default = RegionSetCommand;
RegionSetCommand.description = 'Set region for CLI';
RegionSetCommand.flags = {
    cda: cli_utilities_1.flags.string({
        char: 'd',
        description: 'Custom host to set for content delivery API, if this flag is added then cma, ui-host and name flags are required',
        dependsOn: ['cma', 'ui-host', 'name'],
        parse: (0, cli_utilities_1.printFlagDeprecation)(['-d'], ['--cda']),
    }),
    cma: cli_utilities_1.flags.string({
        char: 'm',
        description: 'Custom host to set for content management API, , if this flag is added then cda, ui-host and name flags are required',
        dependsOn: ['cda', 'ui-host', 'name'],
        parse: (0, cli_utilities_1.printFlagDeprecation)(['-m'], ['--cma']),
    }),
    'ui-host': cli_utilities_1.flags.string({
        description: 'Custom UI host to set for CLI, if this flag is added then cda, cma and name flags are required',
        dependsOn: ['cda', 'cma', 'name'],
    }),
    name: cli_utilities_1.flags.string({
        char: 'n',
        description: 'Name for the region, if this flag is added then cda, cma and ui-host flags are required',
        dependsOn: ['cda', 'cma', 'ui-host'],
    }),
};
RegionSetCommand.examples = [
    '$ csdx config:set:region',
    '$ csdx config:set:region NA',
    '$ csdx config:set:region EU',
    '$ csdx config:set:region AZURE-NA',
    '$ csdx config:set:region AZURE-EU',
    '$ csdx config:set:region --cma <contentstack_cma_endpoint> --cda <contentstack_cda_endpoint> --ui-host <contentstack_ui_host_endpoint> --name "India"',
];
RegionSetCommand.args = {
    region: cli_utilities_1.args.string({ description: 'Name for the region' }),
};
